APP_FOLDER_NAME = '.guet'
DATA_SOURCE_NAME = 'guet.db'
COMMITTER_NAMES = 'committernames'
AUTHOR_NAME = 'authornames'
AUTHOR_EMAIL = 'authoremails'
COMMITTERS = 'committers'
COMMITTERS_SET = 'committersset'
CONFIG = 'config'
ERRORS = 'errors'
